Skip to contents

Decodes the exp claim from the stored JWT refresh token and returns TRUE if the token exists and has a valid expiry.

Usage

vb_refresh_token_is_valid()

Value

Logical TRUE if the refresh token is present and valid, FALSE otherwise.

Examples

if (FALSE) { # \dontrun{
vb_refresh_token_is_valid()
} # }