Skip to contents

Calls the VegBank /refresh endpoint with the currently stored refresh token to obtain a new access token and refresh token, then stores both via vb_set_token().

Usage

vb_refresh_tokens()

Examples

if (FALSE) { # \dontrun{
vb_refresh_tokens()
} # }