Check whether the stored access token is present and not expired
Source:R/vb_auth.R
vb_access_token_is_valid.RdDecodes the exp claim from the stored JWT access token and returns
TRUE if the token exists and has a valid expiry.
R/vb_auth.R
vb_access_token_is_valid.RdDecodes the exp claim from the stored JWT access token and returns
TRUE if the token exists and has a valid expiry.