Check whether the stored refresh token is present and not expired
Source:R/vb_auth.R
vb_refresh_token_is_valid.RdDecodes the exp claim from the stored JWT refresh token and returns
TRUE if the token exists and has a valid expiry.
R/vb_auth.R
vb_refresh_token_is_valid.RdDecodes the exp claim from the stored JWT refresh token and returns
TRUE if the token exists and has a valid expiry.