Calls the VegBank /refresh endpoint with the currently stored refresh
token to obtain a new access token and refresh token, then stores both
via vb_set_token().
Calls the VegBank /refresh endpoint with the currently stored refresh
token to obtain a new access token and refresh token, then stores both
via vb_set_token().